@@ -96,9 +96,7 @@ class LIGAttributions(Attributions):
     def word_attributions(self) -> list:
         wa = []
         if len(self.attributions_sum) >= 1:
-            for i, (word, attribution) in enumerate(
-                zip(self.tokens, self.attributions_sum)
-            ):
+            for i, (word, attribution) in enumerate(zip(self.tokens, self.attributions_sum)):
                 wa.append((word, float(attribution.cpu().data.numpy())))
             return wa
 
@@ -107,13 +105,9 @@ class LIGAttributions(Attributions):
 
     def summarize(self, end_idx=None):
         self.attributions_sum = self._attributions.sum(dim=-1).squeeze(0)
-        self.attributions_sum = self.attributions_sum[:end_idx] / torch.norm(
-            self.attributions_sum[:end_idx]
-        )
+        self.attributions_sum = self.attributions_sum[:end_idx] / torch.norm(self.attributions_sum[:end_idx])
 
-    def visualize_attributions(
-        self, pred_prob, pred_class, true_class, attr_class, all_tokens
-    ):
+    def visualize_attributions(self, pred_prob, pred_class, true_class, attr_class, all_tokens):
 
         return viz.VisualizationDataRecord(
             self.attributions_sum,
